#!/bin/sh

r3_logger() {
  logger -t remoteit "$@"
}

r3_get_architecture() {
  if [ -n "$R3_ARCHITECTURE" ]; then
    echo $R3_ARCHITECTURE
  else
    arch
  fi
}

r3_get_name() {
  if [ -n "$R3_DEVICE_NAME" ]; then
    echo $R3_DEVICE_NAME
  else
    uname -n
  fi
}

r3_get_macaddr() {
  if [ -n "$R3_NETWORK_ADAPTER" ]; then
    ip link show dev $R3_NETWORK_ADAPTER | grep ether | awk '{print $2}'
  else
    ip link show up | grep ether | head -n 1 | awk '{print $2}'
  fi
}

r3_get_model() {
  if [ -r /sys/firmware/devicetree/base/model ]; then
    cat /sys/firmware/devicetree/base/model
  elif [ -r /sys/devices/virtual/dmi/id/product_family ]; then
    cat /sys/devices/virtual/dmi/id/product_family
  else
    echo NOT_DETECTED
  fi
}

r3_get_serial() {
  if [ -r /sys/firmware/devicetree/base/serial-number ]; then
    cat /sys/firmware/devicetree/base/serial-number
  elif [ -r /sys/devices/virtual/dmi/id/product_serial ]; then
    cat /sys/devices/virtual/dmi/id/product_serial
  else
    echo NOT_DETECTED
  fi
}

r3_get_identity() {
  r3_get_macaddr
}

r3_get_manufacturer() {
  echo 34304
}

r3_get_platform() {
  if [ -n "$R3_PLATFORM_CODE" ]; then
    platformcode=$R3_PLATFORM_CODE
    echo $platformcode
  else
    echo 1072
  fi
}

r3_get_metadata() {
  jq -n \
    --arg version "$VERSION" \
    --arg installDir "$REMOTEIT_DIR" \
    --arg macAddress "$(r3_get_macaddr)" \
    --arg model "$(r3_get_model)" \
    --arg serialNum "$(r3_get_serial)" \
    '{$version, $installDir, $macAddress, $model, $serialNum}'
}
